@@ -4,13 +4,13 @@
 # Copyright (c) 2002 Uwe Rathmann, for the original C++ code
 # Copyright (c) 2015 Pierre Raybaut, for the Python translation/optimization
 # (see LICENSE file for more details)
+
 """
 PythonQwt
 =========
 
 The ``PythonQwt`` package is a 2D-data plotting library using Qt graphical
-user interfaces for the Python programming language. It is compatible with
-``PyQt4``, ``PyQt5``, ``PyQt6`` and ``PySide6``.
+user interfaces for the Python programming language.
 
 It consists of a single Python package named `qwt` which is a pure Python
 implementation of Qwt C++ library with some limitations.
@@ -24,44 +24,39 @@ External resources:
 
 .. _PyPI: https://pypi.python.org/pypi/PythonQwt
 .. _GitHubPage: http://pierreraybaut.github.io/PythonQwt
-.. _GitHub: https://github.com/PierreRaybaut/PythonQwt
+.. _GitHub: https://github.com/PlotPyStack/PythonQwt
 """
-__version__ = "0.10.2"
-QWT_VERSION_STR = "6.1.5"
 
 import warnings
 
-from qwt.plot import QwtPlot
-from qwt.symbol import QwtSymbol as QSbl  # see deprecated section
-from qwt.scale_engine import QwtLinearScaleEngine, QwtLogScaleEngine
-from qwt.text import QwtText
-from qwt.plot_canvas import QwtPlotCanvas
-from qwt.plot_curve import QwtPlotCurve as QPC  # see deprecated section
-from qwt.plot_curve import QwtPlotItem
-from qwt.scale_map import QwtScaleMap
+from qwt.color_map import QwtLinearColorMap  # noqa: F401
 from qwt.interval import QwtInterval
-from qwt.legend import QwtLegend, QwtLegendData, QwtLegendLabel
-from qwt.plot_marker import QwtPlotMarker
+from qwt.legend import QwtLegend, QwtLegendData, QwtLegendLabel  # noqa: F401
+from qwt.painter import QwtPainter  # noqa: F401
+from qwt.plot import QwtPlot  # noqa: F401
+from qwt.plot_canvas import QwtPlotCanvas  # noqa: F401
+from qwt.plot_curve import QwtPlotCurve as QPC  # see deprecated section
+from qwt.plot_curve import QwtPlotItem  # noqa: F401
+from qwt.plot_directpainter import QwtPlotDirectPainter  # noqa: F401
 from qwt.plot_grid import QwtPlotGrid as QPG  # see deprecated section
-from qwt.color_map import QwtLinearColorMap
-
-from qwt.toqimage import array_to_qimage as toQImage
-
-from qwt.scale_div import QwtScaleDiv
-from qwt.scale_draw import QwtScaleDraw
-from qwt.scale_draw import QwtAbstractScaleDraw
-from qwt.painter import QwtPainter
-
-from qwt.plot_series import (
-    QwtSeriesData,
-    QwtPointArrayData,
-    QwtSeriesStore,
+from qwt.plot_marker import QwtPlotMarker  # noqa: F401
+from qwt.plot_renderer import QwtPlotRenderer  # noqa: F401
+from qwt.plot_series import (  # noqa: F401
     QwtPlotSeriesItem,
+    QwtPointArrayData,
+    QwtSeriesData,
+    QwtSeriesStore,
 )
+from qwt.scale_div import QwtScaleDiv  # noqa: F401
+from qwt.scale_draw import QwtAbstractScaleDraw, QwtScaleDraw  # noqa: F401
+from qwt.scale_engine import QwtLinearScaleEngine, QwtLogScaleEngine  # noqa: F401
+from qwt.scale_map import QwtScaleMap  # noqa: F401
+from qwt.symbol import QwtSymbol as QSbl  # see deprecated section
+from qwt.text import QwtText  # noqa: F401
+from qwt.toqimage import array_to_qimage as toQImage  # noqa: F401
 
-from qwt.plot_renderer import QwtPlotRenderer
-
-from qwt.plot_directpainter import QwtPlotDirectPainter
+__version__ = "0.12.5"
+QWT_VERSION_STR = "6.1.5"
 
 
 ## ============================================================================
