@@ -28,8 +28,8 @@ QwtAlphaColorMap
    :members:
 """
 
-from qtpy.QtGui import QColor, qRed, qGreen, qBlue, qRgb, qRgba, qAlpha
 from qtpy.QtCore import Qt, qIsNaN
+from qtpy.QtGui import QColor, qAlpha, qBlue, qGreen, qRed, qRgb, qRgba
 
 
 class ColorStop(object):
@@ -91,10 +91,7 @@ class ColorStops(object):
             self.__stops[index].updateSteps(self.__stops[index + 1])
 
     def stops(self):
-        if self.__stops:
-            return [stop.pos for stop in self.__stops]
-        else:
-            return []
+        return self.__stops
 
     def findUpper(self, pos):
         index = 0
