@@ -15,14 +15,13 @@ QwtPlotLayout
 
 import math
 
-from qwt.text import QwtText
-from qwt.scale_widget import QwtScaleWidget
+from qtpy.QtCore import QRectF, QSize, Qt
+from qtpy.QtGui import QFont, QRegion
+
 from qwt.plot import QwtPlot
 from qwt.scale_draw import QwtAbstractScaleDraw
-
-from qtpy.QtGui import QFont, QRegion
-from qtpy.QtCore import QSize, Qt, QRectF
-
+from qwt.scale_widget import QwtScaleWidget
+from qwt.text import QwtText
 
 QWIDGETSIZE_MAX = (1 << 24) - 1
 
@@ -135,7 +134,13 @@ class QwtPlotLayout_LayoutData(object):
                 self.scale[axis].dimWithoutTitle = 0
         layout = plot.canvas().layout()
         if layout is not None:
-            self.canvas.contentsMargins = layout.getContentsMargins()
+            mgn = layout.contentsMargins()
+            self.canvas.contentsMargins = [
+                mgn.left(),
+                mgn.top(),
+                mgn.right(),
+                mgn.bottom(),
+            ]
 
 
 class QwtPlotLayout_PrivateData(object):
@@ -571,7 +576,13 @@ class QwtPlotLayout(object):
         if layout is None:
             left, top, right, bottom = 0, 0, 0, 0
         else:
-            left, top, right, bottom = layout.getContentsMargins()
+            mgn = layout.contentsMargins()
+            left, top, right, bottom = (
+                mgn.left(),
+                mgn.top(),
+                mgn.right(),
+                mgn.bottom(),
+            )
         for axis in QwtPlot.AXES:
             if plot.axisEnabled(axis):
                 scl = plot.axisWidget(axis)
@@ -675,7 +686,7 @@ class QwtPlotLayout(object):
                 if self.__data.legendRatio < 1.0:
                     legendH = min([legendH, int(h / (1.0 - self.__data.legendRatio))])
                 h += legendH + self.__data.spacing
-        return QSize(w, h)
+        return QSize(int(w), int(h))
 
     def layoutLegend(self, options, rect):
         """
