@@ -19,7 +19,6 @@ from qtpy.QtCore import QLineF, QPoint, QPointF, QRect, QRectF, QSize, QSizeF, Q
 from qtpy.QtGui import (
     QBrush,
     QPainter,
-    QPainterPath,
     QPen,
     QPixmap,
     QPolygonF,
@@ -346,7 +345,7 @@ class QwtSymbol_PrivateData(object):
 
         class Path(object):
             def __init__(self):
-                self.path = QPainterPath()
+                self.path = None  # QPainterPath()
                 self.graphic = QwtGraphic()
 
         self.path = Path()
